.. _pyuv:


*********************************************
:py:mod:`pyuv` --- Python interface to libuv.
*********************************************

.. py:module:: pyuv
    :platform: POSIX, Windows
    :synopsis: Python interface to linuv.

.. seealso::
    `libuv's source code
    <http://github.com/joyent/libuv>`_.


Objects
*******

.. toctree::
    :maxdepth: 2
    :titlesonly:

    loop
    handle
    timer
    tcp
    udp
    pipe
    tty
    poll
    process
    async
    prepare
    idle
    check
    signal
    dns
    fs
    error
    errno
    thread
    util

